==> core-4.7.0.tgz: package/src/testing/BaseCliTest.js <==
/**
 * @athenna/core
 *
 * (c) João Lenon <lenon@athenna.io>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
import { pathToFileURL } from 'node:url';
import { Options } from '@athenna/common';
import { BeforeAll } from '@athenna/test';
import { Ignite } from '@athenna/core';
import { TestCommand } from '@athenna/artisan/testing/plugins';
export class BaseCliTest {
    constructor() {
        this.igniteOptions = {};
        this.artisanPath = Path.bootstrap(`artisan.${Path.ext()}`);
    }
    async baseBeforeAll() {
        TestCommand.setArtisanPath(this.artisanPath);
        this.ignite = await new Ignite().load(pathToFileURL(Path.bootstrap(`test.${Path.ext()}`)).href, this.getIgniteOptions());
    }
    getIgniteOptions() {
        return Options.create(this.igniteOptions, {
            bootLogs: false,
            loadConfigSafe: false,
            environments: ['test'],
        });
    }
}
__decorate([
    BeforeAll()
], BaseCliTest.prototype, "baseBeforeAll", null);

==> core-4.9.1.tgz: package/src/testing/BaseCliTest.js <==
/**
 * @athenna/core
 *
 * (c) João Lenon <lenon@athenna.io>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
import { pathToFileURL } from 'node:url';
import { Options } from '@athenna/common';
import { BeforeAll } from '@athenna/test';
import { Ignite } from '@athenna/core';
import { TestCommand } from '@athenna/artisan/testing/plugins';
export class BaseCliTest {
    constructor() {
        this.igniteOptions = {};
        this.artisanPath = Path.bootstrap(`artisan.${Path.ext()}`);
    }
    async baseBeforeAll() {
        TestCommand.setArtisanPath(this.artisanPath);
        this.ignite = await new Ignite().load(pathToFileURL(Path.bootstrap(`test.${Path.ext()}`)).href, this.getIgniteOptions());
    }
    getIgniteOptions() {
        return Options.create(this.igniteOptions, {
            bootLogs: false,
            loadConfigSafe: false,
            environments: ['test']
        });
    }
}
__decorate([
    BeforeAll()
], BaseCliTest.prototype, "baseBeforeAll", null);
